@@ -14,7 +14,7 @@ def get_dupes_inx(hashes_loader):
     return dupes_loader
 
 
-def checkspill(loader1, loader2):
+def check_spill(loader1, loader2):
     hash_loader1, hash_loader2 = [], []
     hasd_1, hasd_2 = {}, {}
     test_spills = []
@@ -42,3 +42,13 @@ def checkspill(loader1, loader2):
             test_spills.append((hasd_1[hsh], hasd_2[hsh]))
 
     return dupes_loader_1, dupes_loader_2, test_spills
+
+
+def check_spill_assert(loader1, loader2):
+    dupes_loader_1, dupes_loader_2, test_spills = check_spill(loader1, loader2)
+    assert (len(test_spills) == 0, f'test set has {len(dupes_loader_1)} spills !')
+    assert (len(dupes_loader_1) == 0, f'Loader 1 had {len(dupes_loader_1)}')
+    assert (len(dupes_loader_2) == 0, f'Loader 2 had {len(dupes_loader_1)}')
+
+
+
